/* MensaplanDatabaseHelper.java
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.dhbwloe.campusapp.database;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;

import java.util.ArrayList;

import de.dhbwloe.campusapp.CampusAppContext;
import de.dhbwloe.campusapp.mensaplan.MensaTagesplan;

/**
 * Created by pk910 on 24.01.2016.
 */
public class MensaplanDatabaseHelper {
    private CampusAppContext AppContext;
    private SQLiteDatabase database;

    public MensaplanDatabaseHelper(CampusAppContext context, SQLiteDatabase database) {
        this.database = database;
        AppContext = context;
    }

    public void updateMensaTagesplan(MensaTagesplan plan) {
        boolean isExisting = false;
        String[] whereArgs = new String[] {
                Long.toString(plan.getPlanDate()),
                plan.getMenuName()
        };
        Cursor resultSet = database.rawQuery("SELECT ChkSum FROM MensaPlan WHERE PlanDate = ? AND MenuName = ?", whereArgs);
        if(resultSet.moveToFirst()) {
            long chksum = resultSet.getLong(0);
            if(plan.getChkSum() == chksum)
                return; // nothing to update
            isExisting = true;
        }
        resultSet.close();

        if(isExisting) {
            try {
                ContentValues updateValues = new ContentValues();
                updateValues.put("ChkSum", plan.getChkSum());
                updateValues.put("Name", plan.getName());
                updateValues.put("NameHtml", plan.getNameHtml());
                updateValues.put("Additional", plan.getAdditional());
                updateValues.put("Notes", plan.getNotes());
                int plainPrice[] = plan.getPlainPrice();
                updateValues.put("PriceStudents", plainPrice[0]);
                updateValues.put("PriceEmployees", plainPrice[1]);
                updateValues.put("PriceGuests", plainPrice[2]);
                updateValues.put("PriceSchool", plainPrice[3]);

                database.update("MensaPlan", updateValues, "PlanDate = ? AND MenuName = ?", whereArgs);
            } catch(Exception e) {
                e.printStackTrace();
            }
        } else {
            try {
                ContentValues indexValues = new ContentValues();
                indexValues.put("PlanDate", plan.getPlanDate());
                indexValues.put("MenuName", plan.getMenuName());

                indexValues.put("ChkSum", plan.getChkSum());
                indexValues.put("Name", plan.getName());
                indexValues.put("NameHtml", plan.getNameHtml());
                indexValues.put("Additional", plan.getAdditional());
                indexValues.put("Notes", plan.getNotes());
                int plainPrice[] = plan.getPlainPrice();
                indexValues.put("PriceStudents", plainPrice[0]);
                indexValues.put("PriceEmployees", plainPrice[1]);
                indexValues.put("PriceGuests", plainPrice[2]);
                indexValues.put("PriceSchool", plainPrice[3]);

                database.insertOrThrow("MensaPlan", null, indexValues);
                plan.setIsNew();
            } catch(Exception e) {
                e.printStackTrace();
            }
        }

    }

    public MensaTagesplan[] getMensaTagesplan(long timeFrom, long timeTo) {
        String[] whereArgs = new String[] {
                Long.toString(timeFrom),
                Long.toString(timeTo)
        };
        Cursor resultSet = database.rawQuery("SELECT PlanDate,MenuName,ChkSum,Name,NameHtml,Additional,Notes,PriceStudents,PriceEmployees,PriceGuests,PriceSchool FROM MensaPlan WHERE PlanDate >= ? AND PlanDate <= ?", whereArgs);
        ArrayList<MensaTagesplan> results = new ArrayList<MensaTagesplan>();
        if(resultSet.moveToFirst()) {
            int[] columnIndexes = {
                    resultSet.getColumnIndex("PlanDate"),
                    resultSet.getColumnIndex("MenuName"),
                    resultSet.getColumnIndex("ChkSum"),
                    resultSet.getColumnIndex("Name"),
                    resultSet.getColumnIndex("NameHtml"),
                    resultSet.getColumnIndex("Additional"),
                    resultSet.getColumnIndex("Notes"),
                    resultSet.getColumnIndex("PriceStudents"),
                    resultSet.getColumnIndex("PriceEmployees"),
                    resultSet.getColumnIndex("PriceGuests"),
                    resultSet.getColumnIndex("PriceSchool")
            };
            do {
                MensaTagesplan plan = new MensaTagesplan(
                        resultSet.getLong(columnIndexes[0]), resultSet.getString(columnIndexes[1]),
                        resultSet.getLong(columnIndexes[2]), resultSet.getString(columnIndexes[3]),
                        resultSet.getString(columnIndexes[4]), resultSet.getString(columnIndexes[5]),
                        resultSet.getString(columnIndexes[6]),
                        resultSet.getInt(columnIndexes[7]), resultSet.getInt(columnIndexes[8]),
                        resultSet.getInt(columnIndexes[9]), resultSet.getInt(columnIndexes[10])
                );

                results.add(plan);
            } while (resultSet.moveToNext());
        }
        resultSet.close();

        MensaTagesplan[] resultsArr = new MensaTagesplan[results.size()];
        resultsArr = results.toArray(resultsArr);
        return resultsArr;
    }

    public long[] getDaysWithPlanData(long timeFrom, long timeTo) {
        String[] whereArgs = new String[] {
                Long.toString(timeFrom),
                Long.toString(timeTo)
        };
        Cursor resultSet = database.rawQuery("SELECT PlanDate FROM MensaPlan WHERE PlanDate >= ? AND PlanDate <= ?  GROUP BY PlanDate", whereArgs);
        ArrayList<Long> results = new ArrayList<Long>();
        if(resultSet.moveToFirst()) {
            do {
                long date = resultSet.getLong(0);

                results.add(date);
            } while (resultSet.moveToNext());
        }
        resultSet.close();

        long[] resultsArr = new long[results.size()];
        for(int i = 0; i < resultsArr.length; i++) {
            resultsArr[i] = results.get(i);
        }
        return resultsArr;
    }

    public long[] getWeeksWithPlanData(long timeFrom, long timeTo) {
        String[] whereArgs = new String[] {
                Long.toString(timeFrom),
                Long.toString(timeTo)
        };
        Cursor resultSet = database.rawQuery("SELECT MIN(PlanDate) AS PlanDate, strftime(\"%W\", PlanDate, \"unixepoch\") AS PlanWeek FROM MensaPlan WHERE PlanDate >= ? AND PlanDate <= ?  GROUP BY PlanWeek", whereArgs);
        ArrayList<Long> results = new ArrayList<Long>();
        if(resultSet.moveToFirst()) {
            do {
                long date = resultSet.getLong(0);

                results.add(date);
            } while (resultSet.moveToNext());
        }
        resultSet.close();

        long[] resultsArr = new long[results.size()];
        for(int i = 0; i < resultsArr.length; i++) {
            resultsArr[i] = results.get(i);
        }
        return resultsArr;
    }

}
