/* NewsDatabaseHelper.java
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.dhbwloe.campusapp.database;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;

import java.util.ArrayList;

import de.dhbwloe.campusapp.CampusAppContext;
import de.dhbwloe.campusapp.news.NewsItem;

/**
 * Created by pk910 on 24.01.2016.
 */
public class NewsDatabaseHelper {
    private CampusAppContext AppContext;
    private SQLiteDatabase database;

    public NewsDatabaseHelper(CampusAppContext context, SQLiteDatabase database) {
        this.database = database;
        AppContext = context;
    }

    public void updateNewsItem(NewsItem news) {
        boolean isExisting = false;
        String[] whereArgs = new String[] {
                news.getSource(),
                news.getUniqueId()
        };
        Cursor resultSet = database.rawQuery("SELECT ChkSum FROM News WHERE Source = ? AND UniqueId = ?", whereArgs);
        if(resultSet.moveToFirst()) {
            long chksum = resultSet.getLong(0);
            if (news.getChkSum() == chksum)
                return; // nothing to update
            isExisting = true;
        }
        resultSet.close();

        if(isExisting) {
            try {
                ContentValues updateValues = new ContentValues();
                updateValues.put("ChkSum", news.getChkSum());
                updateValues.put("Title", news.getTitle());
                updateValues.put("Time", news.getTime());
                updateValues.put("Summary", news.getSummary());
                updateValues.put("Content", news.getContent());
                updateValues.put("Link", news.getLink());
                updateValues.put("Categories", news.getCategories());

                database.update("News", updateValues, "Source = ? AND UniqueId = ?", whereArgs);
            } catch(Exception e) {
                e.printStackTrace();
            }
        } else {
            try {
                ContentValues indexValues = new ContentValues();
                indexValues.put("Source", news.getSource());
                indexValues.put("UniqueId", news.getUniqueId());

                indexValues.put("ChkSum", news.getChkSum());
                indexValues.put("Title", news.getTitle());
                indexValues.put("Time", news.getTime());
                indexValues.put("Summary", news.getSummary());
                indexValues.put("Content", news.getContent());
                indexValues.put("Link", news.getLink());
                indexValues.put("Categories", news.getCategories());

                long newId = database.insertOrThrow("News", null, indexValues);
                news.setIsNew((int) newId);
            } catch(Exception e) {
                e.printStackTrace();
            }
        }

    }

    public NewsItem[] getNewsItems(String source, long timeFrom, long timeTo) {
        String[] whereArgs = new String[] {
                source,
                Long.toString(timeTo),
                Long.toString(timeFrom)
        };
        Cursor resultSet = database.rawQuery("SELECT Id, Source, Time, UniqueId, ChkSum, Title, Summary, Content, Link, Categories FROM News WHERE Source = ? AND Time >= ? AND Time <= ?", whereArgs);
        ArrayList<NewsItem> results = new ArrayList<NewsItem>();
        if(resultSet.moveToFirst()) {
            int[] columnIndexes = {
                    resultSet.getColumnIndex("Id"),
                    resultSet.getColumnIndex("Source"),
                    resultSet.getColumnIndex("Time"),
                    resultSet.getColumnIndex("UniqueId"),
                    resultSet.getColumnIndex("ChkSum"),
                    resultSet.getColumnIndex("Title"),
                    resultSet.getColumnIndex("Summary"),
                    resultSet.getColumnIndex("Content"),
                    resultSet.getColumnIndex("Link"),
                    resultSet.getColumnIndex("Categories")
            };
            do {
                NewsItem news = new NewsItem(
                        resultSet.getInt(columnIndexes[0]), resultSet.getString(columnIndexes[1]),
                        resultSet.getLong(columnIndexes[2]), resultSet.getString(columnIndexes[3]),
                        resultSet.getLong(columnIndexes[4]), resultSet.getString(columnIndexes[5]),
                        resultSet.getString(columnIndexes[6]), resultSet.getString(columnIndexes[7]),
                        resultSet.getString(columnIndexes[8]), resultSet.getString(columnIndexes[9])
                );

                results.add(news);
            } while (resultSet.moveToNext());
        }
        resultSet.close();

        NewsItem[] resultsArr = new NewsItem[results.size()];
        resultsArr = results.toArray(resultsArr);
        return resultsArr;
    }

}
