/* AppSearch.java
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.dhbwloe.campusapp.fragments;
import android.os.Bundle;
import android.support.design.widget.TabLayout;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentManager;
import android.support.v4.app.FragmentPagerAdapter;
import android.support.v4.view.ViewPager;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ListView;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import de.dhbwloe.campusapp.CampusAppContext;
import de.dhbwloe.campusapp.CampusAppFragment;
import de.dhbwloe.campusapp.R;
import de.dhbwloe.campusapp.search.SearchIndices;
import de.dhbwloe.campusapp.search.SearchTarget;

/**
 * A simple {@link Fragment} subclass.
 */
public class AppSearch extends CampusAppFragment {
    private ViewPagerAdapter oAppSearchLViewPagerAdapter;
    private String sSearchQuery;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        Log.i("AppSearch", "Event: onCreate");
        super.onCreate(savedInstanceState);

        Bundle bundle;
        if((bundle = getArguments()) != null)
            sSearchQuery = bundle.getString("query");
        else if(savedInstanceState != null && (bundle = savedInstanceState.getBundle("AppSearch")) != null)
            sSearchQuery = bundle.getString("query");

    }

    @Override
    public void onSaveInstanceState(Bundle savedInstanceState) {
        Log.i("AppSearch", "Event: onSaveInstanceState");
        Bundle bundle = new Bundle();
        bundle.putString("query", sSearchQuery);
        savedInstanceState.putBundle("AppSearch", bundle);
        super.onSaveInstanceState(savedInstanceState);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        Log.i("AppSearch", "Event: onCreateView");
        if(AppContext == null)
            AppContext = CampusAppContext.getInstance();
        oFragmentView = inflater.inflate(R.layout.fragment_appsearch, container, false);

        AppContext.setTitle(AppContext.getResString(R.string.appsearch_title, sSearchQuery));

        ViewPager viewPager = (ViewPager) oFragmentView.findViewById(R.id.viewpager);
        setupViewPager(viewPager);

        TabLayout tabLayout = (TabLayout) oFragmentView.findViewById(R.id.tabs);
        tabLayout.setupWithViewPager(viewPager);

        return oFragmentView;
    }

    private void setupViewPager(ViewPager viewPager) {
        final ViewPagerAdapter adapter;
        if(oAppSearchLViewPagerAdapter != null)
            adapter = oAppSearchLViewPagerAdapter;
        else {
            adapter = new ViewPagerAdapter(getChildFragmentManager());
            oAppSearchLViewPagerAdapter = adapter;

            CampusAppFragment fragment;
            Bundle args = new Bundle();
            args.putString("query", sSearchQuery);
            Log.i("AppSearch", "New result instances: " + sSearchQuery);

            fragment = new AppSearchInternal();
            fragment.setArguments(args);
            adapter.addFragment(AppContext.getResString(R.string.appsearch_inapp), fragment);

            fragment = new AppSearchDhbw();
            fragment.setArguments(args);
            adapter.addFragment(AppContext.getResString(R.string.appsearch_indhbw), fragment);

            fragment = new AppSearchStuv();
            fragment.setArguments(args);
            adapter.addFragment(AppContext.getResString(R.string.appsearch_instuv), fragment);
        }

        viewPager.setAdapter(adapter);
        int activeItem = viewPager.getCurrentItem();
        AppSearchProvider activeProvider = (AppSearchProvider) adapter.getItem(activeItem);
        activeProvider.executeSearch(false);

        viewPager.addOnPageChangeListener(new ViewPager.OnPageChangeListener() {
            @Override
            public void onPageScrolled(int position, float positionOffset, int positionOffsetPixels) {

            }

            @Override
            public void onPageSelected(int position) {
                AppSearchProvider activeProvider = (AppSearchProvider) adapter.getItem(position);
                activeProvider.executeSearch(false);
            }

            @Override
            public void onPageScrollStateChanged(int state) {

            }
        });
    }


    class ViewPagerAdapter extends FragmentPagerAdapter {
        private final List<Fragment> mFragmentDataList = new ArrayList<>();
        private final List<String> mFragmentTitleList = new ArrayList<>();

        public ViewPagerAdapter(FragmentManager manager) {
            super(manager);
        }

        @Override
        public Fragment getItem(int position) {
            return mFragmentDataList.get(position);
        }

        @Override
        public int getCount() {
            return mFragmentDataList.size();
        }

        public void addFragment(String title, Fragment fragment) {
            mFragmentDataList.add(fragment);
            mFragmentTitleList.add(title);
        }

        @Override
        public CharSequence getPageTitle(int position) {
            return mFragmentTitleList.get(position);
        }
    }

}
