/* DashboardVorlesungsplan.java
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.dhbwloe.campusapp.fragments;
import android.os.Build;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.RelativeLayout;
import android.widget.TextView;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

import de.dhbwloe.campusapp.CampusAppContext;
import de.dhbwloe.campusapp.CampusAppFragment;
import de.dhbwloe.campusapp.R;
import de.dhbwloe.campusapp.Tools;
import de.dhbwloe.campusapp.vorlesungen.CourseEvent;

/**
 * A simple {@link Fragment} subclass.
 */
public class DashboardVorlesungsplan extends CampusAppFragment {
    private static int lastGeneratedViewId = 572000;
    private View view;
    private List<CourseEvent> events1 = new ArrayList<CourseEvent>();
    private List<CourseEvent> events2 = new ArrayList<CourseEvent>();
    private String courseName;

    public DashboardVorlesungsplan() {
        // Required empty public constructor
    }


    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        view = inflater.inflate(R.layout.fragment_dashboard_timetable, container, false);
        String kursTag = AppContext.getDatabaseManager().getRuntimeCache("CourseName");
        if(kursTag == null || kursTag.isEmpty()) {
            return view;
        }
        courseName = kursTag;
        return view;
    }

    @Override
    public void onResume() {
        super.onResume();
        if(courseName != null)
            loadViewData();
    }

    private int getDayId(long time) {
        Date date = new Date(time * 1000);
        return getDayId(date);
    }
    private int getDayId(Date date) {
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyyMMdd");
        return Integer.parseInt(dateFormat.format(date));
    }

    private void loadViewData() {
        if(AppContext == null)
            AppContext = CampusAppContext.getInstance();
        long now = (new Date()).getTime() / 1000;
        long tomorrow = now + 86400;

        CourseEvent events[] = AppContext.getDatabaseManager().getCourseCalendarTimetable(courseName, now, 2);
        events1.clear();
        events2.clear();
        if(events.length > 0) {
            int firstDayId = getDayId(events[0].getEventTo());
            for (int i = 0; i < events.length; i++) {
                if (i == 0 || getDayId(events[i].getEventTo()) == firstDayId)
                    events1.add(events[i]);
                else
                    events2.add(events[i]);
            }
        }

        RelativeLayout container;

        container = (RelativeLayout)view.findViewById(R.id.date1Overview);
        buildDayView(container, events1);
        container.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Bundle args = new Bundle();
                if (events1.size() > 0) {
                    long date = events1.get(0).getEventTo();
                    args.putLong("date", date);
                }
                AppContext.getNavigationManager().navigatePage("Vorlesungsplan", args);
            }
        });

        container = (RelativeLayout)view.findViewById(R.id.date2Overview);
        buildDayView(container, events2);
        container.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Bundle args = new Bundle();
                if (events1.size() > 0) {
                    long date = events2.get(0).getEventTo();
                    args.putLong("date", date);
                }
                AppContext.getNavigationManager().navigatePage("Vorlesungsplan", args);
            }
        });

        int todayDayId = getDayId(now);
        int tomorrowDayId = getDayId(tomorrow);
        Date date;

        TextView date1 = (TextView) view.findViewById(R.id.dateView1);
        if(events1.size() > 0) {
            date = new Date(events1.get(0).getEventTo() * 1000);
            date1.setText(getDateText(date, todayDayId, tomorrowDayId));
        } else
            date1.setText("");

        TextView date2 = (TextView) view.findViewById(R.id.dateView2);
        if(events2.size() > 0) {
            date = new Date(events2.get(0).getEventTo() * 1000);
            date2.setText(getDateText(date, todayDayId, tomorrowDayId));
        } else
            date2.setText("");
    }

    private void buildDayView(RelativeLayout container, List<CourseEvent> events) {
        container.removeAllViews();

        Date date;
        TextView leftCol, rightCol = null;
        RelativeLayout.LayoutParams params;
        SimpleDateFormat dateFormat = new SimpleDateFormat(AppContext.getResString(R.string.timeformat_dashboard_vorlesungsplan_time));
        int firstLeftColId = 0;

        if(events.size() > 0) {
            leftCol = new TextView(AppContext.getMainActivity());
            params = new RelativeLayout.LayoutParams(RelativeLayout.LayoutParams.WRAP_CONTENT,
                            RelativeLayout.LayoutParams.WRAP_CONTENT);
            params.setMargins(8, 4, 0, 0);
            leftCol.setLayoutParams(params);
            leftCol.setId(generateViewId());
            firstLeftColId = leftCol.getId();
            container.addView(leftCol);
        } else {
            leftCol = null;
        }

        for(int i = 0; i < events.size(); i++) {
            CourseEvent event = events.get(i);
            date = new Date(event.getEventFrom()*1000);
            leftCol.setText(dateFormat.format(date));

            rightCol = new TextView(AppContext.getMainActivity());
            rightCol.setId(generateViewId());
            params = new RelativeLayout.LayoutParams(RelativeLayout.LayoutParams.WRAP_CONTENT,
                    RelativeLayout.LayoutParams.WRAP_CONTENT);
            params.setMargins(12, 12, 0, 0);
            /*
                    android:layout_alignTop="@+id/date1time2"
                    android:layout_toRightOf="@+id/date1time1"
                    android:layout_toEndOf="@+id/date1time1"
             */
            params.addRule(RelativeLayout.ALIGN_TOP, leftCol.getId());
            params.addRule(RelativeLayout.RIGHT_OF, firstLeftColId);
            params.addRule(RelativeLayout.END_OF, firstLeftColId);
            rightCol.setLayoutParams(params);

            String coursetitle = "";
            if(event.getCourseType() == CourseEvent.CourseType.COURSETYPE_KLAUSUR)
                coursetitle += AppContext.getResString(R.string.dashboard_calendar_klausur);
            coursetitle += event.getEventShortTitle();
            rightCol.setText(coursetitle);


            leftCol = new TextView(AppContext.getMainActivity());
            leftCol.setId(generateViewId());
            params = new RelativeLayout.LayoutParams(RelativeLayout.LayoutParams.WRAP_CONTENT,
                    RelativeLayout.LayoutParams.WRAP_CONTENT);
            params.setMargins(8, -8, 0, 0);
            params.addRule(RelativeLayout.BELOW, rightCol.getId());
            leftCol.setLayoutParams(params);

            date = new Date(event.getEventTo()*1000);
            leftCol.setText(dateFormat.format(date));


            container.addView(rightCol);
            container.addView(leftCol);
        }
    }

    private String getDateText(Date eventDate, int todayDayId, int tomorrowDayId) {
        int date1DayId = getDayId(eventDate);
        String datetext;
        if(date1DayId == todayDayId)
            datetext = AppContext.getResString(R.string.dashboard_calendar_today);
        else if(date1DayId == tomorrowDayId)
            datetext = AppContext.getResString(R.string.dashboard_calendar_tomorrow);
        else {
            String dayStr = Tools.getWeekdayString(eventDate);
            SimpleDateFormat dateFormat = new SimpleDateFormat(AppContext.getResString(R.string.timeformat_dashboard_vorlesungsplan_date));

            datetext = dayStr + ", " + dateFormat.format(eventDate);
        }
        return datetext;
    }

    private int generateViewId() {
        if (Build.VERSION.SDK_INT >= 17)
            return View.generateViewId();
        else
            return lastGeneratedViewId++;
    }

}
