/* Mensa.java
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.dhbwloe.campusapp.fragments;
import android.os.Bundle;
import android.support.design.widget.TabLayout;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentManager;
import android.support.v4.app.FragmentPagerAdapter;
import android.support.v4.view.ViewPager;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

import de.dhbwloe.campusapp.CampusAppFragment;
import de.dhbwloe.campusapp.R;
import de.dhbwloe.campusapp.Tools;
import de.dhbwloe.campusapp.search.SearchIndices;

/**
 * A simple {@link Fragment} subclass.
 */
public class Mensa extends CampusAppFragment {
    /* implement this for search results ;) */
    public static SearchIndices[] GetSearchIndices() {
        return new SearchIndices[] {
                new SearchIndices("Mensa", true) {{
                    setUpdateTime(1);
                    setTarget("#Mensa");
                    setTitle(R.string.search_mensa_title);
                    setDescription(R.string.search_mensa_description);
                    addKeyWord(R.string.search_mensa_keywords);
                }},
        };
    }

    private TabLayout tabLayout;
    private ViewPager viewPager;
    private long viewDate;

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.fragment_mensa, container, false);
        boolean viewmodeSet = false;
        Bundle arguments = getArguments();
        viewDate = (new Date()).getTime()/1000;
        if(arguments != null) {
            String showdate = arguments.getString("showdate");
            long date;
            if(showdate != null && !showdate.isEmpty() && (date = Long.parseLong(showdate)) > 0) {
                viewDate = date;
            }
        }

        AppContext.setTitle(AppContext.getResString(R.string.mensa_title));

        /*
        toolbar = (Toolbar) view.findViewById(R.id.toolbar);
        ((AppCompatActivity) getActivity()).setSupportActionBar(toolbar);

        ((AppCompatActivity) getActivity()).getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        */

        viewPager = (ViewPager) view.findViewById(R.id.viewpager);
        setupViewPager(viewPager);

        tabLayout = (TabLayout) view.findViewById(R.id.tabs);
        tabLayout.setupWithViewPager(viewPager);

        return view;
    }

    private void setupViewPager(ViewPager viewPager) {
        final ViewPagerAdapter adapter = new ViewPagerAdapter(getChildFragmentManager());

        long[] showDates;
        long now = (new Date()).getTime()/1000;
        if(viewDate < now)
            now = viewDate;

        Calendar cal = Calendar.getInstance();
        cal.setTime(new Date(now * 1000));
        cal.set(Calendar.HOUR_OF_DAY, 0);
        cal.set(Calendar.MINUTE, 0);
        cal.set(Calendar.SECOND, 0);
        cal.set(Calendar.MILLISECOND, 0);
        long midnight = cal.getTimeInMillis() / 1000;
        int dow = cal.get(Calendar.DAY_OF_WEEK);
        dow -= 2;
        if(dow < 0) // monday should be 0!
            dow += 7;
        long subTimeToWeekStart = (86400 * dow);
        long showDateFrom = midnight - subTimeToWeekStart;

        showDates = AppContext.getDatabaseManager().getDaysWithPlanData(showDateFrom, now + (30 * 86400));

        int activeItem = -1;
        long activeItemDiff = -1;
        Bundle args = getArguments();
        int lastWeekday = 0;
        for(int i = 0; i < showDates.length; i++) {
            long date = showDates[i];
            Bundle bundle = new Bundle();
            if(args != null)
                bundle.putAll(args);
            String title;
            SimpleDateFormat sdf;

            cal.setTime(new Date(date * 1000));
            int weekday = cal.get(Calendar.DAY_OF_WEEK);
            weekday -= 2; // monday should be 0!
            if(weekday < 0)
                weekday += 7;

            if(viewDate > 0) {
                long diff = Math.abs(viewDate - date);
                if(activeItem == -1 || diff < activeItemDiff) {
                    activeItem = i;
                    activeItemDiff = diff;
                }
            }

            if(lastWeekday > weekday) {
                adapter.addFragment(null, null);
            }
            lastWeekday = weekday;

            title = Tools.getWeekdayString(date, false);
            bundle.putLong("date", date);
            adapter.addFragment(bundle, title);
        }
        viewPager.setAdapter(adapter);
        viewPager.setCurrentItem(activeItem);

        MensaTagesplan tagesplan = (MensaTagesplan)adapter.getItem(activeItem);
        tagesplan.onSetActive();


        viewPager.addOnPageChangeListener(new ViewPager.OnPageChangeListener() {
            @Override
            public void onPageScrolled(int position, float positionOffset, int positionOffsetPixels) {

            }

            @Override
            public void onPageSelected(int position) {
                MensaTagesplan tagesplan = (MensaTagesplan)adapter.getItem(position);
                tagesplan.onSetActive();
            }

            @Override
            public void onPageScrollStateChanged(int state) {

            }
        });
    }


    class ViewPagerAdapter extends FragmentPagerAdapter {
        private final List<Fragment> mFragmentList = new ArrayList<>();
        private final List<Bundle> mFragmentDataList = new ArrayList<>();
        private final List<String> mFragmentTitleList = new ArrayList<>();

        public ViewPagerAdapter(FragmentManager manager) {
            super(manager);
        }

        @Override
        public Fragment getItem(int position) {
            Fragment fragment;
            while(mFragmentList.size() <= position) {
                mFragmentList.add(null);
            }
            if(mFragmentList.get(position) != null)
                return mFragmentList.get(position);
            fragment = new MensaTagesplan();

            fragment.setArguments(mFragmentDataList.get(position));
            mFragmentList.set(position, fragment);
            return fragment;
        }

        @Override
        public int getCount() {
            return mFragmentDataList.size();
        }

        public void addFragment(Bundle fragmentdata, String title) {
            if(title == null) {
                Bundle bnd = new Bundle();
                bnd.putBoolean("parentIsMensaFragment", true);
                mFragmentDataList.add(bnd);
                mFragmentTitleList.add("");
                return;
            }

            fragmentdata.putBoolean("parentIsMensaFragment", true);
            mFragmentDataList.add(fragmentdata);
            mFragmentTitleList.add(title);
        }

        @Override
        public CharSequence getPageTitle(int position) {
            return mFragmentTitleList.get(position);
        }
    }

}
