/* MensaTagesplan.java
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.dhbwloe.campusapp.fragments;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ListView;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;

import de.dhbwloe.campusapp.CampusAppContext;
import de.dhbwloe.campusapp.CampusAppFragment;
import de.dhbwloe.campusapp.R;

/**
 * A simple {@link Fragment} subclass.
 */
public class MensaTagesplan extends CampusAppFragment {
    private ArrayList<de.dhbwloe.campusapp.mensaplan.MensaTagesplan> tagesplanMenueItems = new ArrayList<>();
    private Date viewPlanDate;
    private boolean setActiveOnLoad = false;
    private boolean redirectPage = true;

    public void onSetActive() {
        if(AppContext == null)
            AppContext = CampusAppContext.getInstance();
        if(viewPlanDate == null) {
            AppContext.setTitle("");
            setActiveOnLoad = true;
            return;
        }
        SimpleDateFormat titleDateFormater = new SimpleDateFormat(AppContext.getResString(R.string.timeformat_mensa_titledate));
        AppContext.setTitle(AppContext.getResString(R.string.mensa_dayplan_title, titleDateFormater.format(viewPlanDate)));
    }

    private void setupPlanDate() {
        Bundle args = getArguments();
        Date planDay = null;
        if(args != null) {
            boolean mensaparent = args.getBoolean("parentIsMensaFragment");
            if(mensaparent)
                redirectPage = false;
            long plandate = args.getLong("date");
            if(plandate > 0) {
                planDay = new Date(plandate * 1000);
                DateFormat justDay = new SimpleDateFormat("yyyyMMdd");
                try {
                    planDay = justDay.parse(justDay.format(planDay));
                } catch (Exception e) {
                }
            }
        }
        if(planDay == null) {
            return;
        }
        viewPlanDate = planDay;
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setupPlanDate();

    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.fragment_mensa_tagesplan, container, false);

        if(viewPlanDate == null) {
            if(redirectPage)
                AppContext.getNavigationManager().navigatePage("Mensa", null, false); // silent redirect
            else {
                return inflater.inflate(R.layout.fragment_mensa_weekend, container, false);
            }
            return null;
        }
        if(setActiveOnLoad) {
            setActiveOnLoad = false;
            onSetActive();
        }

        ListView tagesplanItemsList = (ListView) view.findViewById(R.id.tagesplanItems);
        MensaTagesplanListAdapter listAdapter = new MensaTagesplanListAdapter(view.getContext(), R.layout.fragment_mensa_tagesplan_listitem, tagesplanMenueItems);
        tagesplanItemsList.setAdapter(listAdapter);

        tagesplanItemsList.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
                de.dhbwloe.campusapp.mensaplan.MensaTagesplan item = tagesplanMenueItems.get(position);
                if (item == null)
                    return;

                // do sth?
            }
        });

        requestMenues();

        return view;
    }

    private void requestMenues() {
        Date endOfDay = (Date)viewPlanDate.clone();
        endOfDay.setTime(endOfDay.getTime() + (86400 - 1) * 1000);

        de.dhbwloe.campusapp.mensaplan.MensaTagesplan menues[] = AppContext.getDatabaseManager().getMensaTagesplan(viewPlanDate.getTime()/1000, endOfDay.getTime()/1000);
        tagesplanMenueItems.clear();
        for(de.dhbwloe.campusapp.mensaplan.MensaTagesplan menue : menues) {
            tagesplanMenueItems.add(menue);
        }

    }

}
