/* NewsListAdapter.java
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.dhbwloe.campusapp.fragments;
import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import java.util.ArrayList;

import de.dhbwloe.campusapp.R;

/**
 * Created by pk910 on 27.02.2016.
 */
public class NewsListAdapter  extends ArrayAdapter<NewsListItem> {
    private Context context;
    private int layoutResourceId;
    private ArrayList<NewsListItem> data = new ArrayList<NewsListItem>();

    public NewsListAdapter(Context context, int layoutResourceId, ArrayList<NewsListItem> data) {
        super(context, layoutResourceId, data);
        this.layoutResourceId = layoutResourceId;
        this.context = context;
        this.data = data;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        View row = convertView;
        RecordHolder holder = null;

        if (row == null) {
            LayoutInflater inflater = (LayoutInflater)context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
            row = inflater.inflate(layoutResourceId, parent, false);

            holder = new RecordHolder(row);
            row.setTag(holder);
        } else {
            holder = (RecordHolder) row.getTag();
        }

        final NewsListAdapter that = this;
        final NewsListItem item = data.get(position);

        holder.newsTitle.setText(item.getFormatedDate() + ": " + item.getTitle());
        holder.newsDescription.setText(item.getDescription());
        if(item.isDhbwNews()) {
            holder.newsDhbwLogo.setVisibility(View.VISIBLE);
            holder.newsStuvLogo.setVisibility(View.GONE);
        } else {
            holder.newsDhbwLogo.setVisibility(View.GONE);
            holder.newsStuvLogo.setVisibility(View.VISIBLE);
        }

        return row;
    }

    static class RecordHolder {
        TextView newsTitle;
        TextView newsDescription;
        ImageView newsDhbwLogo;
        ImageView newsStuvLogo;

        public RecordHolder(View view) {
            this.newsTitle = (TextView) view.findViewById(R.id.newsTitleView);
            this.newsDescription = (TextView) view.findViewById(R.id.newsDescriptionView);

            newsDhbwLogo = (ImageView) view.findViewById(R.id.dhbwLogo);
            newsStuvLogo = (ImageView) view.findViewById(R.id.stuvLogo);
        }
    }
}
