/* NewsListItem.java
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.dhbwloe.campusapp.fragments;
import java.text.SimpleDateFormat;
import java.util.Date;

import de.dhbwloe.campusapp.CampusAppContext;
import de.dhbwloe.campusapp.R;
import de.dhbwloe.campusapp.news.NewsItem;
import de.dhbwloe.campusapp.vorlesungen.CourseEvent;

/**
 * Created by pk910 on 27.02.2016.
 */
public class NewsListItem {
    private String sNewsTitle;
    private String sNewsDescription;
    private String sNewsLink;
    private long lNewsDate;
    private boolean bIsDhbwNews;
    private boolean bIsEvent;

    public NewsListItem(NewsItem newsItem, boolean isDhbwNews) {
        sNewsTitle = newsItem.getTitle();
        sNewsDescription = newsItem.getSummary();
        sNewsLink = newsItem.getLink();
        lNewsDate = newsItem.getTime();
        bIsDhbwNews = isDhbwNews;
        bIsEvent = false;
    }

    public NewsListItem(CourseEvent newsEvent, boolean isDhbwEvent) {
        sNewsTitle = newsEvent.getEventTitle();
        sNewsDescription = newsEvent.getEventLocation();
        sNewsLink = null;
        lNewsDate = newsEvent.getEventFrom();
        bIsDhbwNews = isDhbwEvent;
        bIsEvent = true;
    }

    public long getTimeDifference(long now) {
        return Math.abs(now - lNewsDate);
    }

    public String getTitle() {
        return sNewsTitle;
    }

    public String getDescription() {
        return sNewsDescription;
    }

    public boolean isDhbwNews() {
        return bIsDhbwNews;
    }

    public String getFormatedDate() {
        String dateFormat;
        if(bIsEvent)
            dateFormat = CampusAppContext.getInstance().getResString(R.string.timeformat_news_event);
        else
            dateFormat = CampusAppContext.getInstance().getResString(R.string.timeformat_news_news);
        SimpleDateFormat format = new SimpleDateFormat(dateFormat);
        return format.format(new Date(lNewsDate * 1000));
    }

    public String getLink() {
        return sNewsLink;
    }
}
