/* PopupFragment.java
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.dhbwloe.campusapp.fragments;
import android.content.DialogInterface;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentTransaction;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.PopupWindow;

import de.dhbwloe.campusapp.CampusAppContext;
import de.dhbwloe.campusapp.CampusAppFragment;
import de.dhbwloe.campusapp.R;
import de.dhbwloe.campusapp.search.SearchIndices;
import de.dhbwloe.campusapp.search.SearchTarget;

/**
 * Created by pk910 on 21.01.2016.
 */
public class PopupFragment extends DialogFragment {
    private CampusAppContext AppContext;
    private CampusAppFragment oCurrentFragment;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        AppContext = CampusAppContext.getInstance();
        super.onCreate(savedInstanceState);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.content_popup, container, false);
        getDialog().setOnCancelListener(new DialogInterface.OnCancelListener() {
            @Override
            public void onCancel(DialogInterface dialog) {
                AppContext.getNavigationManager().closeDialog();
            }
        });

        Bundle args = getArguments();
        if(args != null) {
            String targetPage = args.getString("target");
            SearchTarget target = new SearchTarget(targetPage);
            String targetPageName;
            if(target.isInAppTarget())
                targetPageName = target.getTargetUrl();
            else {
                targetPageName = "WebBrowser";
                args.putString("url", target.getTargetUrl());
            }
            CampusAppFragment fragment = AppContext.getNavigationManager().getPageFragment(targetPageName);
            fragment.setArguments(args);

            FragmentTransaction transaction = getChildFragmentManager().beginTransaction();
            transaction.add(R.id.content_container, fragment);
            oCurrentFragment = fragment;
            transaction.commit();
        }

        return view;
    }

    public void destroyView() {
        if(oCurrentFragment != null) {
            CampusAppFragment fragment = oCurrentFragment;
            oCurrentFragment = null;
            if(fragment.isAdded()) {
                FragmentTransaction transaction = getChildFragmentManager().beginTransaction();
                transaction.remove(fragment);
                transaction.commit();
            } else
                AppContext.getMainActivity().onBackPressed();
        }
    }

    public CampusAppFragment getCurrentFragment() {
        return oCurrentFragment;
    }

}