/* VorlesungsplanExams.java
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.dhbwloe.campusapp.fragments;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ListView;

import java.util.ArrayList;
import java.util.Date;

import de.dhbwloe.campusapp.CampusAppFragment;
import de.dhbwloe.campusapp.R;
import de.dhbwloe.campusapp.vorlesungen.CourseEvent;
import de.dhbwloe.campusapp.vorlesungen.CourseGroup;

/**
 * A simple {@link Fragment} subclass.
 */
public class VorlesungsplanExams extends CampusAppFragment implements Vorlesungsplan.VorlesungsplanFragment {
    private String coursename;
    private View view;
    private VorlesungsplanExamsListAdapter listAdapter;
    private ArrayList<VorlesungsplanExamsListItem> listItems = new ArrayList<VorlesungsplanExamsListItem>();

    public VorlesungsplanExams() {
        // Required empty public constructor
    }


    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        String kursTag = AppContext.getDatabaseManager().getRuntimeCache("CourseName");
        if(kursTag == null || kursTag.isEmpty())
            return null;
        coursename = kursTag;

        view = inflater.inflate(R.layout.fragment_vorlesungsplan_exams, container, false);

        ListView listView = (ListView) view.findViewById(R.id.listView);
        listAdapter = new VorlesungsplanExamsListAdapter(view.getContext(), R.layout.fragment_vorlesungsplan_exams_exam, listItems);
        listView.setAdapter(listAdapter);

        return view;
    }

    @Override
    public void setActive() {

    }

    @Override
    public void onResume() {
        super.onResume();
        if(coursename != null)
            updateCoursesList();
    }

    private void updateCoursesList() {
        long now = (new Date()).getTime()/1000;

        CourseEvent[] events = AppContext.getDatabaseManager().getCourseExamEvents(coursename, now, now + (86400 * 30 * 6)); // next 6 month
        listItems.clear();
        for(CourseEvent event : events) {

            VorlesungsplanExamsListItem item = new VorlesungsplanExamsListItem(
                    event.getEventId(),
                    coursename,
                    event.getEventTitle(),
                    event.getEventLocation(),
                    event.getEventFrom(),
                    event.getEventTo(),
                    1
            );
            listItems.add(item);
        }
        if(listAdapter != null)
            listAdapter.notifyDataSetChanged();
    }

}
