/* VorlesungsplanGroupsListAdapter.java
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.dhbwloe.campusapp.fragments;
import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.LinearLayout;
import android.widget.TextView;

import java.util.ArrayList;

import de.dhbwloe.campusapp.CampusAppContext;
import de.dhbwloe.campusapp.R;

/**
 * Created by pk910 on 20.02.2016.
 */
public class VorlesungsplanGroupsListAdapter extends ArrayAdapter<VorlesungsplanGroupsListItem> {
    private Context context;
    private int layoutResourceId;
    private ArrayList<VorlesungsplanGroupsListItem> data = new ArrayList<VorlesungsplanGroupsListItem>();

    public VorlesungsplanGroupsListAdapter(Context context, int layoutResourceId, ArrayList<VorlesungsplanGroupsListItem> data) {
        super(context, layoutResourceId, data);
        this.layoutResourceId = layoutResourceId;
        this.context = context;
        this.data = data;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        View row = convertView;
        RecordHolder holder = null;

        if (row == null) {
            LayoutInflater inflater = (LayoutInflater)context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
            row = inflater.inflate(layoutResourceId, parent, false);

            holder = new RecordHolder(row);
            row.setTag(holder);
        } else {
            holder = (RecordHolder) row.getTag();
        }

        final VorlesungsplanGroupsListAdapter that = this;
        final VorlesungsplanGroupsListItem item = data.get(position);

        holder.groupName.setText(item.getGroupName());
        holder.nextEvent.setText(item.getNextEvent());
        holder.lastEvent.setText(item.getLastEvent());

        String klausurDate = item.getNextKlausurEvent();
        if(klausurDate == null)
            klausurDate = CampusAppContext.getInstance().getResString(R.string.vorlesungsplan_groups_noklausur);

        holder.klausurEvent.setText(klausurDate);
        
        return row;
    }

    static class RecordHolder {
        TextView groupName;
        TextView nextEvent;
        TextView lastEvent;
        TextView klausurEvent;
        TextView klausurName;

        public RecordHolder(View view) {
            this.groupName = (TextView) view.findViewById(R.id.courseTitle);
            this.nextEvent = (TextView) view.findViewById(R.id.nextEvent);
            this.lastEvent = (TextView) view.findViewById(R.id.lastEvent);
            this.klausurEvent = (TextView) view.findViewById(R.id.klausurEvent);
            this.klausurName = (TextView) view.findViewById(R.id.klausurName);
        }
    }
}
