/* VorlesungsplanUpcoming.java
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.dhbwloe.campusapp.fragments;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ListView;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;

import de.dhbwloe.campusapp.CampusAppContext;
import de.dhbwloe.campusapp.CampusAppFragment;
import de.dhbwloe.campusapp.R;
import de.dhbwloe.campusapp.vorlesungen.CourseEvent;

/**
 * A simple {@link Fragment} subclass.
 */
public class VorlesungsplanUpcoming extends CampusAppFragment implements Vorlesungsplan.VorlesungsplanFragment {
    private View view;
    private String courseName;
    private ArrayList<VorlesungsplanUpcomingDayListItem> upcomingDays = new ArrayList<VorlesungsplanUpcomingDayListItem>();
    private VorlesungsplanUpcomingDayListAdapter upcomingDaysAdapter;

    public VorlesungsplanUpcoming() {
        // Required empty public constructor
    }


    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        view = inflater.inflate(R.layout.fragment_vorlesungsplan_upcoming, container, false);

        String kursTag = AppContext.getDatabaseManager().getRuntimeCache("CourseName");
        if(kursTag == null || kursTag.isEmpty()) {
            return null;
        }
        courseName = kursTag;

        ListView listView = (ListView) view.findViewById(R.id.listView);
        upcomingDaysAdapter = new VorlesungsplanUpcomingDayListAdapter(view.getContext(), R.layout.fragment_vorlesungsplan_upcoming_day, upcomingDays);
        listView.setAdapter(upcomingDaysAdapter);

        return view;
    }

    @Override
    public void setActive() {

    }

    @Override
    public void onResume() {
        super.onResume();
        if(courseName != null)
            refreshUpcomingEvents();
    }

    private int getDayId(long time) {
        Date date = new Date(time * 1000);
        return getDayId(date);
    }
    private int getDayId(Date date) {
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyyMMdd");
        return Integer.parseInt(dateFormat.format(date));
    }

    private void refreshUpcomingEvents() {
        if(AppContext == null)
            AppContext = CampusAppContext.getInstance();
        long now = (new Date()).getTime() / 1000;

        CourseEvent events[] = AppContext.getDatabaseManager().getCourseCalendarTimetable(courseName, now, 365);
        int lastDayId = 0;
        VorlesungsplanUpcomingDayListItem lastDayItem = null;
        upcomingDays.clear();
        for(int i = 0; i < events.length; i++) {
            int dayId = getDayId(events[i].getEventTo());
            if(dayId > lastDayId) {
                lastDayItem = new VorlesungsplanUpcomingDayListItem(events[i].getEventTo());
                upcomingDays.add(lastDayItem);
                lastDayId = dayId;
            }
            lastDayItem.addCourseEvent(events[i]);
        }
        if(upcomingDaysAdapter != null) {
            upcomingDaysAdapter.notifyDataSetChanged();
        }
    }

}
