/* MensaTagesplan.java
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.dhbwloe.campusapp.mensaplan;
import java.text.DateFormat;
import java.text.DecimalFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;
import java.util.zip.CRC32;

import de.dhbwloe.campusapp.CampusAppContext;
import de.dhbwloe.campusapp.R;

/**
 * Created by pk910 on 22.01.2016.
 */
public class MensaTagesplan {
    private long iPlanDate;
    private long iChkSum;
    private String sMenuName, sName, sNameHtml, sAdditional, sNotes;
    private int[] aPriceArray = new int[4];

    private boolean bIsNew = false;

    public MensaTagesplan(long plandate, String menuname, long chksum, String name, String namehtml, String additional, String notes, int price1, int price2, int price3, int price4) {
        iPlanDate = plandate;
        sMenuName = menuname;
        iChkSum = chksum;
        sName = name;
        sNameHtml = namehtml;
        sAdditional = (additional == null ? "" : additional);
        sNotes = notes;
        aPriceArray[0] = price1; // Student
        aPriceArray[1] = price2; // Employees
        aPriceArray[2] = price3; // Guest
        aPriceArray[3] = price4; // School
    }

    public long calculateChkSum() {
        CRC32 crc = new CRC32();
        crc.update(sMenuName.getBytes());
        if(sName != null)
            crc.update(sName.getBytes());
        if(sNameHtml != null)
            crc.update(sNameHtml.getBytes());
        if(sAdditional!= null)
            crc.update(sAdditional.getBytes());
        if(sNotes!= null)
            crc.update(sNotes.getBytes());
        crc.update(aPriceArray[0]);
        crc.update(aPriceArray[1]);
        crc.update(aPriceArray[2]);
        crc.update(aPriceArray[3]);

        long crcvalue = crc.getValue();
        iChkSum = crcvalue;
        return crcvalue;
    }

    public long getPlanDate() {
        return iPlanDate;
    }

    public String getFormatedDate() {
        DateFormat df = new SimpleDateFormat("dd.MM.yyyy", Locale.ENGLISH);
        return df.format(new Date(iPlanDate * 1000));
    }

    public long getChkSum() {
        return iChkSum;
    }

    public String getMenuName() {
        return sMenuName;
    }

    public String getName() {
        return sName;
    }

    public String getNameHtml() {
        return sNameHtml;
    }

    public String getAdditional() {
        return sAdditional;
    }

    public String getNotes() {
        return sNotes;
    }

    public int[] getPlainPrice() {
        return aPriceArray;
    }

    public double getStudentPrice() {
        double price = (aPriceArray[0] / 100.0);
        return price;
    }

    public double getEmployeePrice() {
        double price = (aPriceArray[1] / 100.0);
        return price;
    }

    public double getGuestPrice() {
        double price = (aPriceArray[2] / 100.0);
        return price;
    }

    public double getSchoolPrice() {
        double price = (aPriceArray[3] / 100.0);
        return price;
    }

    public String getFormatedRolePrice() {
        String mensaRoleName = CampusAppContext.getInstance().getDatabaseManager().getRuntimeCache("MensaRole");
        if (mensaRoleName == null || mensaRoleName.isEmpty())
            mensaRoleName = "0";
        int mensaRole = Integer.parseInt(mensaRoleName);
        double price = (aPriceArray[mensaRole] / 100.0);

        DecimalFormat df = new DecimalFormat(CampusAppContext.getInstance().getResString(R.string.mensaformat_price));
        String formatedPrice = df.format(price);
        return formatedPrice;
    }

    public void setIsNew() {
        bIsNew = true;
    }

    public boolean getIsNew(boolean reset) {
        boolean isnew = bIsNew;
        if(reset)
            bIsNew = false;
        return isnew;
    }

}
