/* XmlRequestHelper.java
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.dhbwloe.campusapp.network;
import android.os.Bundle;
import android.util.Log;

import com.loopj.android.http.AsyncHttpClient;
import com.loopj.android.http.AsyncHttpResponseHandler;

import net.fortuna.ical4j.data.CalendarBuilder;
import net.fortuna.ical4j.data.ParserException;
import net.fortuna.ical4j.model.Calendar;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlPullParserFactory;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.UnsupportedEncodingException;
import java.security.KeyStore;
import java.util.ArrayList;
import java.util.List;

import cz.msebera.android.httpclient.Header;

/**
 * Created by pk910 on 20.01.2016.
 */
public abstract class XmlRequestHelper {
    private static final String ns = null;
    private String sRootElementName, sElementName;

    protected void requestXmlFromWeb(String url, String rootElementName, String elementName) {
        AsyncHttpClient client = new AsyncHttpClient();

        sRootElementName = rootElementName;
        sElementName = elementName;

        Log.i("HTTPClient", "Request: "+url);
        client.get(url, new AsyncHttpResponseHandler() {
            @Override
            public void onStart() {
            }

            @Override
            public void onSuccess(int statusCode, Header[] headers, byte[] response) {
                ByteArrayInputStream inputStream = new ByteArrayInputStream(response);
                List<XmlEntry> entries = parseXml(inputStream, sRootElementName, sElementName);

                onXmlReceived(entries);
            }

            @Override
            public void onFailure(int statusCode, Header[] headers, byte[] errorResponse, Throwable e) {
                String error = null;
                try {
                    error = new String(errorResponse, "US-ASCII");
                } catch (Exception e1) {
                }
                Log.i("HTTPClient", "  Error: " + statusCode + " - " + error);
                onXmlRequestFail(statusCode, error);
            }

            @Override
            public void onRetry(int retryNo) {
            }
        });
    }

    public static List<XmlEntry> parseXml(InputStream input, String rootElementName, String elementName) {
        List<XmlEntry> entries = null;
        try {
            XmlPullParserFactory xmlFactoryObject = XmlPullParserFactory.newInstance();
            XmlPullParser myparser = xmlFactoryObject.newPullParser();

            myparser.setInput(input, null);

            do {
                myparser.nextTag();
            } while(!myparser.getName().equalsIgnoreCase(rootElementName));

            entries = readXml(myparser, rootElementName, elementName);
        } catch (Exception e) {
            e.printStackTrace();
        }

        return entries;
    }

    private static List<XmlEntry> readXml(XmlPullParser parser, String rootElementName, String elementName) throws XmlPullParserException, IOException {
        List<XmlEntry> entries = new ArrayList<XmlEntry>();

        parser.require(XmlPullParser.START_TAG, ns, rootElementName);
        while (parser.next() != XmlPullParser.END_TAG) {

            if (parser.getEventType() != XmlPullParser.START_TAG) {
                continue;
            }
            String name = parser.getName();
            // Starts by looking for the entry tag
            if (name.equalsIgnoreCase(elementName)) {
                Log.i("XMLParser", "found "+elementName);
                entries.add(readXmlEntry(parser, elementName));
            } else {
                entries.addAll(readXml(parser, name, elementName));
            }
        }
        return entries;
    }

    private static XmlEntry readXmlEntry(XmlPullParser parser, String elementName) throws XmlPullParserException, IOException {
        parser.require(XmlPullParser.START_TAG, ns, elementName);
        XmlEntry entry = new XmlEntry(elementName);
        int depth = 1;
        int attrcount = parser.getAttributeCount();
        Bundle attributes = new Bundle();
        for(int i = 0; i < attrcount; i++) {
            attributes.putString(parser.getAttributeName(i), parser.getAttributeValue(i));
        }
        entry.setAttributes(attributes);
        while (depth != 0) {
            switch (parser.next()) {
                case XmlPullParser.START_TAG:
                    XmlEntry child = readXmlEntry(parser, parser.getName());
                    entry.addChild(child);
                    break;
                case XmlPullParser.END_TAG:
                    depth = 0;
                    break;
                case XmlPullParser.TEXT:
                    entry.setValue(parser.getText());
                    break;
            }
        }
        return entry;
    }

    private static void skip(XmlPullParser parser) throws XmlPullParserException, IOException {
        if (parser.getEventType() != XmlPullParser.START_TAG) {
            throw new IllegalStateException();
        }
        int depth = 1;
        while (depth != 0) {
            switch (parser.next()) {
                case XmlPullParser.END_TAG:
                    depth--;
                    break;
                case XmlPullParser.START_TAG:
                    depth++;
                    break;
            }
        }
    }

    protected abstract void onXmlReceived(List<XmlEntry> entries);
    protected abstract void onXmlRequestFail(int statusCode, String errorMessage);

}
