/* SearchTarget.java
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.dhbwloe.campusapp.search;

import android.os.Bundle;

import java.net.URLDecoder;
import java.net.URLEncoder;

import de.dhbwloe.campusapp.NavigationManager;

/**
 * Created by pk910 on 19.01.2016.
 */
public class SearchTarget {
    private boolean bInAppTarget = false;
    private String sTargetUrl = null;
    private Bundle oArguments = new Bundle();

    public SearchTarget(String target) {
        if(target.startsWith("#")) { // InApp Navigation
            bInAppTarget = true;
            target = target.substring(1);
        }
        String[] parts = target.split("#", 2);
        if(parts.length != 0)
            sTargetUrl = parts[0];
        if(parts.length > 1) {
            // parse arguments?
            String[] args = parts[1].split("&");
            for(int i = 0; i < args.length; i++) {
                String[] arg = args[i].split("=");
                try {
                    if (arg.length == 2)
                        oArguments.putString(URLDecoder.decode(arg[0], "UTF-8"), URLDecoder.decode(arg[1], "UTF-8"));
                    else
                        oArguments.putBoolean(URLDecoder.decode(arg[0], "UTF-8"), true);
                } catch(Exception e) {}
            }
        }

    }

    public SearchTarget() {
    }

    public boolean isInAppTarget() {
        return bInAppTarget;
    }

    public void setInAppTarget(boolean inAppTarget) {
        bInAppTarget = inAppTarget;
    }

    public String getTargetUrl() {
        return sTargetUrl;
    }

    public void setTargetUrl(String url) {
        sTargetUrl = url;
    }

    public void setArgument(String name, String value) {
        oArguments.putString(name, value);
    }

    public void navigate(NavigationManager navigationManager) {
        Bundle args = oArguments;
        if(bInAppTarget)
            navigationManager.navigatePage(sTargetUrl, args);
        else {
            args.putString("url", sTargetUrl);
            navigationManager.navigatePage("WebBrowser", args, false);
        }
    }
}
