/* CourseEvent.java
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package de.dhbwloe.campusapp.vorlesungen;
import net.fortuna.ical4j.model.Component;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import de.dhbwloe.campusapp.database.DatabaseManager;

/**
 * Created by pk910 on 20.01.2016.
 */
public class CourseEvent implements Comparable<CourseEvent> {
    public enum CourseType {
        COURSETYPE_NORMAL,
        COURSETYPE_SPECIAL,
        COURSETYPE_KLAUSUR,
    }

    private int iEventId;
    private String sCourseName;
    private String sUniqueId;
    private int iSequenceId;
    private long iEventFrom, iEventTo;
    private String sEventTitle, sEventTitleShort, sEventTitleAuthor, sEventLocation, sEventStatus;
    private String sRecurRule, sExcludeDates;
    private CourseGroup oCourseGroup;
    private CourseType oCourseType = null;

    private boolean bMustUpdate = false;
    private boolean bIsNew = false;

    private boolean bIsKlausurPraesi = false;

    public CourseEvent(int id, String coursename, String uniqueid, int sequenceid, long eventfrom, long eventto, String title, String location, String status, String rrule, String exdates, CourseGroup group, int eventtype) {
        iEventId = id;
        sCourseName = coursename;
        sUniqueId = uniqueid;
        iSequenceId = sequenceid;
        iEventFrom = eventfrom;
        iEventTo = eventto;
        sEventTitle = title;
        sEventLocation = location;
        sEventStatus = status;
        sRecurRule = rrule;
        sExcludeDates = exdates;

        oCourseGroup = group;
        if(group != null) {
            group.addCourseEvent(this);
            try {
                oCourseType = CourseType.values()[eventtype];
            } catch(Exception e) {}
        }

        ParseEventTitle();
    }

    public CourseEvent(String coursename, String uniqueid, int sequenceid, boolean isNew) {
        sCourseName = coursename;
        sUniqueId = uniqueid;
        iSequenceId = sequenceid;
        bIsNew = isNew;
        bMustUpdate = isNew;
    }

    public void ParseEventTitle() {
        Pattern pattern = Pattern.compile("^((Klausur|Tutorium|Pr(ä|ae)sentation)[ :]+)?(.*?)( - ([a-zA-Z., -]+))?$");
        Matcher m = pattern.matcher(sEventTitle);
        CourseType oldtype = oCourseType;
        boolean typeisset = (oCourseType != null);
        if (m.matches()) {
            String eventType = m.group(2);
            if (!typeisset && eventType != null && !eventType.isEmpty()) {
                if(eventType.equalsIgnoreCase("Klausur"))
                    oCourseType = CourseType.COURSETYPE_KLAUSUR;
                else if(eventType.equalsIgnoreCase("Präsentation") || eventType.equalsIgnoreCase("Praesentation")) {
                    oCourseType = CourseType.COURSETYPE_KLAUSUR;
                    bIsKlausurPraesi = true;
                } else if(eventType.equalsIgnoreCase("Tutorium"))
                    oCourseType = CourseType.COURSETYPE_SPECIAL;

                typeisset = true;
            }
            sEventTitleShort = m.group(4);
            sEventTitleAuthor = m.group(6);
        } else {
            sEventTitleShort = sEventTitle;
            sEventTitleAuthor = "";
        }
        if(!typeisset)
            oCourseType = CourseType.COURSETYPE_NORMAL;

        if(oldtype != oCourseType)
            bMustUpdate = true;
    }

    public void setEventId(int id) {
        iEventId = id;
    }

    public int getEventId() {
        return iEventId;
    }

    private void resetUpdateFlag() {
        bIsNew = false;
        bMustUpdate = false;
    }

    public void update(DatabaseManager dbm, Component event) {
        if(!bMustUpdate)
            return;

        dbm.updateCourseCalendar(this, event);
        resetUpdateFlag();
    }

    public CourseGroup getCourseGroup() {
        return oCourseGroup;
    }

    public void setCourseType(CourseType type) {
        oCourseType = type;
    }

    public CourseType getCourseType() {
        return oCourseType;
    }

    public int getCourseTypeId() {
        for(int i = 0; i < CourseType.values().length; i++) {
            if(oCourseType == CourseType.values()[i])
                return i;
        }
        return 0;
    }

    public void setCourseGroup(CourseGroup group) {
        group.addCourseEvent(this);
        oCourseGroup = group;
    }

    public String getUniqueId() {
        return sUniqueId;
    }

    public boolean IsPendingUpdate() {
        return bMustUpdate;
    }

    public boolean IsNewEvent() {
        return bIsNew;
    }

    public String getEventStatus() {
        return sEventStatus;
    }

    public void setEventStatus(String sEventStatus) {
        this.sEventStatus = sEventStatus;
        bMustUpdate = true;
    }

    public String getEventLocation() {
        return sEventLocation;
    }

    public void setEventLocation(String sEventLocation) {
        this.sEventLocation = sEventLocation;
        bMustUpdate = true;
    }

    public String getEventTitle() {
        return sEventTitle;
    }
    public String getGroupTitle() {
        return sEventTitleShort + (sEventTitleAuthor == null ? "" : " - " + sEventTitleAuthor);
    }
    public String getEventShortTitle() {
        return sEventTitleShort;
    }
    public String getEventDozent() {
        return sEventTitleAuthor;
    }

    public void setEventTitle(String sEventTitle) {
        this.sEventTitle = sEventTitle;
        ParseEventTitle();
        bMustUpdate = true;
    }

    public long getEventTo() {
        return iEventTo;
    }

    public void setEventTo(long iEventTo) {
        this.iEventTo = iEventTo;
        bMustUpdate = true;
    }

    public long getEventFrom() {
        return iEventFrom;
    }

    public void setEventFrom(long iEventFrom) {
        this.iEventFrom = iEventFrom;
        bMustUpdate = true;
    }

    public String getCourseName() {
        return sCourseName;
    }

    public int getSequenceId() {
        return iSequenceId;
    }

    public void setSequenceId(int iSequenceId) {
        this.iSequenceId = iSequenceId;
        bMustUpdate = true;
    }

    public String getRecurRule() {
        return sRecurRule;
    }

    public void setRecurRule(String rrule) {
        this.sRecurRule = rrule;
        bMustUpdate = true;
    }

    public String getExcludeDates() {
        return sExcludeDates;
    }

    public void setExcludeDates(String exrules) {
        this.sExcludeDates = exrules;
        bMustUpdate = true;
    }

    public boolean getIsKlausurPraesi() {
        return bIsKlausurPraesi;
    }

    @Override
    public int compareTo(CourseEvent another) {
        return (int)(another.getEventFrom() - iEventFrom);
    }
}
